==> wikitty-api-3.1.2-sources.jar: org/nuiton/wikitty/search/FacetTopicNameComparator.java <==
/*
 * #%L
 * Wikitty :: api
 * 
 * $Id: FacetTopicNameComparator.java 875 2011-05-09 14:14:54Z sletellier $
 * $HeadURL: http://svn.nuiton.org/svn/wikitty/tags/wikitty-3.1.2/wikitty-api/src/main/java/org/nuiton/wikitty/search/FacetTopicNameComparator.java $
 * %%
 * Copyright (C) 2009 - 2011 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */
package org.nuiton.wikitty.search;

import java.util.Comparator;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 *
 * @author poussin
 * @version $Revision: 875 $
 *
 * Last update: $Date: 2011-05-09 16:14:54 +0200 (lun., 09 mai 2011) $
 * by : $Author: sletellier $
 */
public class FacetTopicNameComparator implements Comparator<FacetTopic> {

    /** to use log facility, just put in your code: log.info(\"...\"); */
    static private Log log = LogFactory.getLog(FacetTopicNameComparator.class);

    protected boolean ignoreCase = true;

    public FacetTopicNameComparator() {
    }

    public FacetTopicNameComparator(boolean ignoreCase) {
        this.ignoreCase = ignoreCase;
    }
    
    public int compare(FacetTopic o1, FacetTopic o2) {
        int result;
        if (ignoreCase) {
            result = o1.getTopicName().compareToIgnoreCase(o2.getTopicName());   
        } else {
            result = o1.getTopicName().compareTo(o2.getTopicName());
        }
        return result;
    }
}

==> wikitty-api-3.2-sources.jar: org/nuiton/wikitty/search/FacetTopicNameComparator.java <==
/*
 * #%L
 * Wikitty :: api
 * 
 * $Id: FacetTopicNameComparator.java 1136 2011-08-12 14:24:03Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/wikitty/tags/wikitty-3.2/wikitty-api/src/main/java/org/nuiton/wikitty/search/FacetTopicNameComparator.java $
 * %%
 * Copyright (C) 2009 - 2011 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */
package org.nuiton.wikitty.search;

import java.util.Comparator;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 *
 * @author poussin
 * @version $Revision: 1136 $
 *
 * Last update: $Date: 2011-08-12 16:24:03 +0200 (Fri, 12 Aug 2011) $
 * by : $Author: tchemit $
 */
public class FacetTopicNameComparator implements Comparator<FacetTopic> {

    /** to use log facility, just put in your code: log.info(\"...\"); */
    static private Log log = LogFactory.getLog(FacetTopicNameComparator.class);

    protected boolean ignoreCase = true;

    public FacetTopicNameComparator() {
    }

    public FacetTopicNameComparator(boolean ignoreCase) {
        this.ignoreCase = ignoreCase;
    }
    
    public int compare(FacetTopic o1, FacetTopic o2) {
        int result;
        if (ignoreCase) {
            result = o1.getTopicName().compareToIgnoreCase(o2.getTopicName());   
        } else {
            result = o1.getTopicName().compareTo(o2.getTopicName());
        }
        return result;
    }
}
